@@ -95,8 +95,8 @@ def validate_site(site: dict, nodes=[]):
         validate_value_min_max(site.get('measurements')),
         validate_list_duplicates(site, 'measurements', [
             'term.@id',
-            'method.@id',
-            'methodDescription',
+            'methodModel.@id',
+            'methodModelDescription',
             'startDate',
             'endDate',
             'depthUpper',
